varying lowp vec2 v_texCoord;
varying lowp vec2 v_texCoord2;
uniform lowp sampler2D u_texture;

void main()
{
    // the normal to a edge vector  which govern what part of the half circle
    // score bar should be rendered and not is encoded in the xy coordinates of the uv2 set
    lowp vec2 edgeNormal = v_texCoord2.xy;
    
    // transform the current texture coordinate to the space of this vector{(-1, 1), (0, 1)}
    // the y coordinate must grow upward instead of downward so it is inverted
    lowp vec2 currentPoint = vec2(v_texCoord.x * 2.0 - 1.0, 1.0 - v_texCoord.y);
    
    // Set highp to both of them to be able to work on all Devices since only using lowp in diffuse 
    // caused some problems on Galaxy Tab 2
	highp float projection = dot(currentPoint, edgeNormal);
	highp vec4 diffuse = texture2D(u_texture, v_texCoord.xy);
    
    // only draw the score bar if its texture coordinate is on the left side of the edge
    // ie. if its position projected onto the edge normal is greater than 0
    // use smooth step in a small space to remove aliasing effects of step
    float alpha = smoothstep(0.0, 0.02, projection) * diffuse.a;
    
    gl_FragColor = vec4(diffuse.rgb, alpha);
}
