varying lowp vec4 v_color;
varying lowp vec2 v_texCoord;

uniform lowp sampler2D u_texture;

// This is a masking shader which draws each pixel with either the color passed from the vertex shader or the monocrome color value
// from the green channel in the texture. The shader decides which color to use by looking at the red channel of the texture. If the
// red channel has a value closer to 0.0, the shader draws the color passed as from the vertex shader. If the value is closer to 1.0,
// the shader draws the monochrome value from the green channel of the texture. It shall also interpolate between and retain alpha
// from the texture. 

// The shader does the masking by using mix (a.k.a. lerp) from vertex color to green channel and using the red channel as an interpolator. 
 
void main() 
{
	lowp vec4 texColor = texture2D(u_texture, v_texCoord);

	gl_FragColor = vec4(mix(v_color.rgb, texColor.ggg, texColor.r), texColor.a);
}